"""
Copyright 2021-2024 MICRORISC s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
from abc import ABC, abstractmethod
from logging import Logger

from Setter.Logging import Logging


class IqarosConfig(ABC):
	"""
	IQAROS gateway configuration base class.

	Methods
	-------
	configure() -> None:
		Configure IQAROS gateway.
	get_services() -> List[str]:
		Return IQAROS services to restart.
	"""

	_logger: Logger = Logging.get_logger()

	@classmethod
	@abstractmethod
	def configure(cls) -> None:
		"""
		Configure IQAROS gateway.

		Returns
		-------
		None
		"""

	@classmethod
	def get_services(cls) -> list[str]:
		"""
		Return IQAROS services to restart.

		Returns
		-------
		list[str]
			IQAROS services to restart
		"""
		return []
